@@ -13,10 +13,19 @@ import sys
 from datetime import datetime
 from typing import List
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
+from mypy_boto3_workmail.literals import (
+    AccessControlRuleEffect,
+    EntityState,
+    FolderName,
+    MailboxExportJobState,
+    MemberType,
+    MobileDeviceAccessRuleEffect,
+    PermissionType,
+    ResourceType,
+    RetentionAction,
+    UserRole,
+)
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -74,7 +83,7 @@ AccessControlRuleTypeDef = TypedDict(
     "AccessControlRuleTypeDef",
     {
         "Name": str,
-        "Effect": Literal["ALLOW", "DENY"],
+        "Effect": AccessControlRuleEffect,
         "Description": str,
         "IpRanges": List[str],
         "NotIpRanges": List[str],
@@ -98,14 +107,10 @@ BookingOptionsTypeDef = TypedDict(
     total=False,
 )
 
-DelegateTypeDef = TypedDict("DelegateTypeDef", {"Id": str, "Type": Literal["GROUP", "USER"]})
+DelegateTypeDef = TypedDict("DelegateTypeDef", {"Id": str, "Type": MemberType})
 
 _RequiredFolderConfigurationTypeDef = TypedDict(
-    "_RequiredFolderConfigurationTypeDef",
-    {
-        "Name": Literal["INBOX", "DELETED_ITEMS", "SENT_ITEMS", "DRAFTS", "JUNK_EMAIL"],
-        "Action": Literal["NONE", "DELETE", "PERMANENTLY_DELETE"],
-    },
+    "_RequiredFolderConfigurationTypeDef", {"Name": FolderName, "Action": RetentionAction}
 )
 _OptionalFolderConfigurationTypeDef = TypedDict(
     "_OptionalFolderConfigurationTypeDef", {"Period": int}, total=False
@@ -124,7 +129,7 @@ GroupTypeDef = TypedDict(
         "Id": str,
         "Email": str,
         "Name": str,
-        "State": Literal["ENABLED", "DISABLED", "DELETED"],
+        "State": EntityState,
         "EnabledDate": datetime,
         "DisabledDate": datetime,
     },
@@ -140,7 +145,7 @@ MailboxExportJobTypeDef = TypedDict(
         "S3BucketName": str,
         "S3Path": str,
         "EstimatedProgress": int,
-        "State": Literal["RUNNING", "COMPLETED", "FAILED", "CANCELLED"],
+        "State": MailboxExportJobState,
         "StartTime": datetime,
         "EndTime": datetime,
     },
@@ -152,8 +157,8 @@ MemberTypeDef = TypedDict(
     {
         "Id": str,
         "Name": str,
-        "Type": Literal["GROUP", "USER"],
-        "State": Literal["ENABLED", "DISABLED", "DELETED"],
+        "Type": MemberType,
+        "State": EntityState,
         "EnabledDate": datetime,
         "DisabledDate": datetime,
     },
@@ -172,7 +177,7 @@ MobileDeviceAccessRuleTypeDef = TypedDict(
         "MobileDeviceAccessRuleId": str,
         "Name": str,
         "Description": str,
-        "Effect": Literal["ALLOW", "DENY"],
+        "Effect": MobileDeviceAccessRuleEffect,
         "DeviceTypes": List[str],
         "NotDeviceTypes": List[str],
         "DeviceModels": List[str],
@@ -201,11 +206,7 @@ OrganizationSummaryTypeDef = TypedDict(
 
 PermissionTypeDef = TypedDict(
     "PermissionTypeDef",
-    {
-        "GranteeId": str,
-        "GranteeType": Literal["GROUP", "USER"],
-        "PermissionValues": List[Literal["FULL_ACCESS", "SEND_AS", "SEND_ON_BEHALF"]],
-    },
+    {"GranteeId": str, "GranteeType": MemberType, "PermissionValues": List[PermissionType]},
 )
 
 ResourceTypeDef = TypedDict(
@@ -214,8 +215,8 @@ ResourceTypeDef = TypedDict(
         "Id": str,
         "Email": str,
         "Name": str,
-        "Type": Literal["ROOM", "EQUIPMENT"],
-        "State": Literal["ENABLED", "DISABLED", "DELETED"],
+        "Type": ResourceType,
+        "State": EntityState,
         "EnabledDate": datetime,
         "DisabledDate": datetime,
     },
@@ -231,8 +232,8 @@ UserTypeDef = TypedDict(
         "Email": str,
         "Name": str,
         "DisplayName": str,
-        "State": Literal["ENABLED", "DISABLED", "DELETED"],
-        "UserRole": Literal["USER", "RESOURCE", "SYSTEM_USER"],
+        "State": EntityState,
+        "UserRole": UserRole,
         "EnabledDate": datetime,
         "DisabledDate": datetime,
     },
@@ -265,7 +266,7 @@ DescribeGroupResponseTypeDef = TypedDict(
         "GroupId": str,
         "Name": str,
         "Email": str,
-        "State": Literal["ENABLED", "DISABLED", "DELETED"],
+        "State": EntityState,
         "EnabledDate": datetime,
         "DisabledDate": datetime,
     },
@@ -283,7 +284,7 @@ DescribeMailboxExportJobResponseTypeDef = TypedDict(
         "S3Prefix": str,
         "S3Path": str,
         "EstimatedProgress": int,
-        "State": Literal["RUNNING", "COMPLETED", "FAILED", "CANCELLED"],
+        "State": MailboxExportJobState,
         "ErrorInfo": str,
         "StartTime": datetime,
         "EndTime": datetime,
@@ -313,9 +314,9 @@ DescribeResourceResponseTypeDef = TypedDict(
         "ResourceId": str,
         "Email": str,
         "Name": str,
-        "Type": Literal["ROOM", "EQUIPMENT"],
+        "Type": ResourceType,
         "BookingOptions": "BookingOptionsTypeDef",
-        "State": Literal["ENABLED", "DISABLED", "DELETED"],
+        "State": EntityState,
         "EnabledDate": datetime,
         "DisabledDate": datetime,
     },
@@ -329,8 +330,8 @@ DescribeUserResponseTypeDef = TypedDict(
         "Name": str,
         "Email": str,
         "DisplayName": str,
-        "State": Literal["ENABLED", "DISABLED", "DELETED"],
-        "UserRole": Literal["USER", "RESOURCE", "SYSTEM_USER"],
+        "State": EntityState,
+        "UserRole": UserRole,
         "EnabledDate": datetime,
         "DisabledDate": datetime,
     },
@@ -341,7 +342,7 @@ DomainTypeDef = TypedDict("DomainTypeDef", {"DomainName": str, "HostedZoneId": s
 
 GetAccessControlEffectResponseTypeDef = TypedDict(
     "GetAccessControlEffectResponseTypeDef",
-    {"Effect": Literal["ALLOW", "DENY"], "MatchedRules": List[str]},
+    {"Effect": AccessControlRuleEffect, "MatchedRules": List[str]},
     total=False,
 )
 
@@ -363,7 +364,7 @@ GetMailboxDetailsResponseTypeDef = TypedDict(
 GetMobileDeviceAccessEffectResponseTypeDef = TypedDict(
     "GetMobileDeviceAccessEffectResponseTypeDef",
     {
-        "Effect": Literal["ALLOW", "DENY"],
+        "Effect": MobileDeviceAccessRuleEffect,
         "MatchedRules": List["MobileDeviceAccessMatchedRuleTypeDef"],
     },
     total=False,
